@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Vroom;
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 use Vroom::Mo;
 
 use File::HomeDir;
@@ -635,6 +635,8 @@ sub parseSlideConfig {
             if $option =~ /^cd/;
         $config->{$1} = 1
             if $option =~ /^(config|skip|center|replace|$type_list)$/;
+        $config->{$1} = 1
+            if $option =~ /^(\.\w+)$/;
         $config->{indent} = $1
             if $option =~ /i(\d+)/;
         $config->{undent} = $1
@@ -696,6 +698,10 @@ sub applyOptions {
                 last;
             }
         }
+        elsif ($key =~ s/^\.(\w+)//) {
+            $ext = ".$1";
+            last;
+        }
     }
     $self->ext($ext);
 
